"""Claims models."""

from django.contrib.postgres.fields import ArrayField
from django.db import models

from dfhir.base.models import (
    Address,
    Attachment,
    BaseReference,
    CodeableConcept,
    Identifier,
    Money,
    OrganizationReference,
    Period,
    Quantity,
    Reference,
    SimpleQuantity,
    TimeStampedModel,
)

from . import choices


class ClaimEntererReference(BaseReference):
    """Claim Enterer Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="claim_enterer_reference_identifier",
        null=True,
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.CASCADE,
        related_name="claim_enterer_reference_practitioner",
        null=True,
    )
    practitioner_role = models.ForeignKey(
        "practitionerroles.PractitionerRole",
        on_delete=models.CASCADE,
        related_name="claim_enterer_reference_practitioner_role",
        null=True,
    )
    patient = models.ForeignKey(
        "patients.Patient",
        on_delete=models.CASCADE,
        related_name="claim_enterer_reference_patient",
        null=True,
    )
    related_person = models.ForeignKey(
        "relatedpersons.RelatedPerson",
        on_delete=models.CASCADE,
        related_name="claim_enterer_reference_related_person",
        null=True,
    )


class ClaimProviderReference(BaseReference):
    """Claim Provider Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="claim_provider_reference_identifier",
        null=True,
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.CASCADE,
        related_name="claim_provider_reference_practitioner",
        null=True,
    )
    practitioner_role = models.ForeignKey(
        "practitionerroles.PractitionerRole",
        on_delete=models.CASCADE,
        related_name="claim_provider_reference_practitioner_role",
        null=True,
    )
    organization = models.ForeignKey(
        "organizations.Organization",
        on_delete=models.CASCADE,
        related_name="claim_provider_reference_organization",
        null=True,
    )


class ClaimRelated(TimeStampedModel):
    """Claim related model."""

    claim = models.ForeignKey(
        "ClaimReference",
        on_delete=models.CASCADE,
        related_name="claim_related_claim",
        null=True,
    )
    relationship = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="claim_related_relationship",
        null=True,
    )
    reference = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="claim_related_reference",
        null=True,
    )


class ClaimPrescriptionReference(BaseReference):
    """Claim Prescription Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="claim_prescription_reference_identifier",
        null=True,
    )
    device_request = models.ForeignKey(
        "devicerequests.DeviceRequest",
        on_delete=models.CASCADE,
        related_name="claim_prescription_reference_device_request",
        null=True,
    )
    medication_request = models.ForeignKey(
        "medicationrequests.MedicationRequest",
        on_delete=models.CASCADE,
        related_name="claim_prescription_reference_medication_request",
        null=True,
    )
    vision_prescription = models.ForeignKey(
        "visionprescriptions.VisionPrescription",
        on_delete=models.CASCADE,
        related_name="claim_prescription_reference_vision_prescription",
        null=True,
    )


class ClaimOriginalPrescriptionReference(BaseReference):
    """Claim Original Prescription Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="claim_original_prescription_reference_identifier",
        null=True,
    )
    device_request = models.ForeignKey(
        "devicerequests.DeviceRequest",
        on_delete=models.CASCADE,
        related_name="claim_original_prescription_reference_device_request",
        null=True,
    )
    medication_request = models.ForeignKey(
        "medicationrequests.MedicationRequest",
        on_delete=models.CASCADE,
        related_name="claim_original_prescription_reference_medication_request",
        null=True,
    )
    vision_prescription = models.ForeignKey(
        "visionprescriptions.VisionPrescription",
        on_delete=models.CASCADE,
        related_name="claim_original_prescription_reference_vision_prescription",
        null=True,
    )


class ClaimPayeePartyReference(BaseReference):
    """Claim Payee Party Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="claim_payee_party_reference_identifier",
        null=True,
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.CASCADE,
        related_name="claim_payee_party_reference_practitioner",
        null=True,
    )
    practitioner_role = models.ForeignKey(
        "practitionerroles.PractitionerRole",
        on_delete=models.CASCADE,
        related_name="claim_payee_party_reference_practitioner_role",
        null=True,
    )
    organization = models.ForeignKey(
        "organizations.Organization",
        on_delete=models.CASCADE,
        related_name="claim_payee_party_reference_organization",
        null=True,
    )
    patient = models.ForeignKey(
        "patients.Patient",
        on_delete=models.CASCADE,
        related_name="claim_payee_party_reference_patient",
        null=True,
    )
    related_person = models.ForeignKey(
        "relatedpersons.RelatedPerson",
        on_delete=models.CASCADE,
        related_name="claim_payee_party_reference_related_person",
        null=True,
    )


class ClaimPayee(TimeStampedModel):
    """Claim payee model."""

    type = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="claim_payee_type",
        null=True,
    )
    party = models.ForeignKey(
        ClaimPayeePartyReference,
        on_delete=models.CASCADE,
        related_name="claim_payee_party",
        null=True,
    )


class ClaimCareTeamProviderReference(BaseReference):
    """Care Team Provider Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="claim_care_team_provider_reference_identifier",
        null=True,
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.CASCADE,
        related_name="claim_care_team_provider_reference_practitioner",
        null=True,
    )
    practitioner_role = models.ForeignKey(
        "practitionerroles.PractitionerRole",
        on_delete=models.CASCADE,
        related_name="claim_care_team_provider_reference_practitioner_role",
        null=True,
    )
    organization = models.ForeignKey(
        "organizations.Organization",
        on_delete=models.CASCADE,
        related_name="claim_care_team_provider_reference_organization",
        null=True,
    )


class ClaimCareTeam(TimeStampedModel):
    """Claim care team model."""

    sequence = models.IntegerField(null=True)
    provider = models.ForeignKey(
        ClaimCareTeamProviderReference,
        on_delete=models.CASCADE,
        related_name="claim_care_team_provider",
        null=True,
    )
    responsible = models.BooleanField(default=False)
    role = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="claim_care_team_role",
        null=True,
    )
    specialty = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="claim_care_team_specialty",
        null=True,
    )


class ClaimSupportingInfo(TimeStampedModel):
    """Claim supporting info model."""

    sequence = models.IntegerField(null=True)
    category = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="claim_supporting_info_category",
        null=True,
    )
    code = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="claim_supporting_info_code",
        null=True,
    )
    timing_date = models.DateField(null=True)
    timing_period = models.ForeignKey(
        Period,
        on_delete=models.CASCADE,
        related_name="claim_supporting_info_timing_period",
        null=True,
    )
    value_boolean = models.BooleanField(null=True)
    value_string = models.CharField(max_length=255, null=True)
    value_quantity = models.ForeignKey(
        Quantity,
        on_delete=models.CASCADE,
        related_name="claim_supporting_info_value_quantity",
        null=True,
    )
    value_attachment = models.ForeignKey(
        Attachment,
        on_delete=models.CASCADE,
        related_name="claim_supporting_info_value_attachment",
        null=True,
    )
    value_reference = models.ForeignKey(
        Reference,
        on_delete=models.CASCADE,
        related_name="claim_supporting_info_value_reference",
        null=True,
    )
    value_identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="claim_supporting_info_value_identifier",
        null=True,
    )
    reason = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="claim_supporting_info_reason",
        null=True,
    )


class ClaimDiagnosis(TimeStampedModel):
    """Claim diagnosis model."""

    sequence = models.IntegerField(null=True)
    diagnosis_codeable_concept = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="claim_diagnosis_diagnosis_codeable_concept",
        null=True,
    )
    diagnosis_reference = models.ForeignKey(
        Reference,
        on_delete=models.CASCADE,
        related_name="claim_diagnosis_diagnosis_reference",
        null=True,
    )
    type = models.ManyToManyField(
        CodeableConcept,
        related_name="claim_diagnosis_type",
        blank=True,
    )
    on_admission = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="claim_diagnosis_on_admission",
        null=True,
    )


class ClaimProcedure(TimeStampedModel):
    """Claim procedure model."""

    sequence = models.IntegerField(null=True)
    type = models.ManyToManyField(
        CodeableConcept,
        related_name="claim_procedure_type",
        blank=True,
    )
    date = models.DateField(null=True)
    procedure_codeable_concept = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="claim_procedure_procedure_codeable_concept",
        null=True,
    )
    procedure_reference = models.ForeignKey(
        "procedures.ProcedureReference",
        on_delete=models.CASCADE,
        related_name="claim_procedure_procedure_reference",
        null=True,
    )
    udi = models.ManyToManyField(
        "devices.DeviceReference",
        related_name="claim_procedure_udi",
        blank=True,
    )


class ClaimInsurance(TimeStampedModel):
    """Claim insurance model."""

    sequence = models.IntegerField(null=True)
    focal = models.BooleanField(default=False)
    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="claim_insurance_identifier",
        null=True,
    )
    coverage = models.ForeignKey(
        "coverages.CoverageReference",
        on_delete=models.CASCADE,
        related_name="claim_insurance_coverage",
        null=True,
    )
    business_arrangement = models.CharField(max_length=255, null=True)
    pre_auth_ref = ArrayField(models.CharField(max_length=255), null=True)
    # claim_response = models.ForeignKey(
    #     "claimresponses.ClaimResponse",
    #     on_delete=models.CASCADE,
    #     related_name="claim_insurance_claim_response",
    #     null=True,
    # )


class ClaimAccident(TimeStampedModel):
    """Claim accident model."""

    date = models.DateField(null=True)
    type = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="claim_accident_type",
        null=True,
    )
    location_address = models.ForeignKey(
        Address,
        on_delete=models.CASCADE,
        related_name="claim_accident_location_address",
        null=True,
    )
    location_reference = models.ForeignKey(
        "locations.LocationReference",
        on_delete=models.CASCADE,
        related_name="claim_accident_location_reference",
        null=True,
    )


class ClaimItemRequestReference(BaseReference):
    """Claim Item Request Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="claim_item_request_reference_identifier",
        null=True,
    )
    device_request = models.ForeignKey(
        "devicerequests.DeviceRequest",
        on_delete=models.CASCADE,
        related_name="claim_item_request_reference_device_request",
        null=True,
    )
    medication_request = models.ForeignKey(
        "medicationrequests.MedicationRequest",
        on_delete=models.CASCADE,
        related_name="claim_item_request_reference_medication_request",
        null=True,
    )
    nutrition_order = models.ForeignKey(
        "nutritionorders.NutritionOrder",
        on_delete=models.CASCADE,
        related_name="claim_item_request_reference_nutrition_order",
        null=True,
    )
    service_request = models.ForeignKey(
        "servicerequests.ServiceRequest",
        on_delete=models.CASCADE,
        related_name="claim_item_request_reference_service_request",
        null=True,
    )
    supply_request = models.ForeignKey(
        "supplyrequests.SupplyRequest",
        on_delete=models.CASCADE,
        related_name="claim_item_request_reference_supply_request",
        null=True,
    )
    vision_prescription = models.ForeignKey(
        "visionprescriptions.VisionPrescription",
        on_delete=models.CASCADE,
        related_name="claim_item_request_reference_vision_prescription",
        null=True,
    )


class ClaimItemBodySIte(TimeStampedModel):
    """Claim Item Body Site model."""

    site = models.ManyToManyField(
        "bodystructures.BodyStructureCodeableReference",
        related_name="claim_item_body_site",
        blank=True,
    )
    sub_site = models.ManyToManyField(
        CodeableConcept,
        related_name="claim_item_sub_site",
        blank=True,
    )


class ClaimItemDetailSubDetail(TimeStampedModel):
    """Claim item detail sub detail."""

    sequence = models.IntegerField(null=True)
    trace_number = models.ManyToManyField(
        Identifier,
        related_name="claim_item_detail_sub_detail_trace_number",
        blank=True,
    )
    revenue = models.ForeignKey(
        CodeableConcept,
        related_name="claim_item_detail_sub_detail_revenue",
        on_delete=models.CASCADE,
        null=True,
    )
    category = models.ForeignKey(
        CodeableConcept,
        related_name="claim_item_detail_sub_detail_category",
        on_delete=models.CASCADE,
        null=True,
    )
    product_or_service = models.ForeignKey(
        CodeableConcept,
        related_name="claim_item_detail_sub_detail_product_or_service",
        on_delete=models.CASCADE,
        null=True,
    )
    product_or_service_end = models.ForeignKey(
        CodeableConcept,
        related_name="claim_item_detail_sub_detail_product_or_service_end",
        on_delete=models.CASCADE,
        null=True,
    )
    modifier = models.ManyToManyField(
        CodeableConcept,
        related_name="claim_item_detail_sub_detail_modifier",
        blank=True,
    )
    program_code = models.ManyToManyField(
        CodeableConcept,
        related_name="claim_item_detail_sub_detail_program_code",
        blank=True,
    )
    patient_paid = models.ForeignKey(
        Money,
        related_name="claim_item_detail_sub_detail_patient_paid",
        on_delete=models.CASCADE,
        null=True,
    )
    quantity = models.ForeignKey(
        SimpleQuantity,
        related_name="claim_item_detail_sub_detail_quantity",
        on_delete=models.CASCADE,
        null=True,
    )
    unit_price = models.ForeignKey(
        Money,
        related_name="claim_item_detail_sub_detail_unit_price",
        on_delete=models.CASCADE,
        null=True,
    )
    factor = models.FloatField(null=True)
    tax = models.ForeignKey(
        Money,
        related_name="claim_item_detail_sub_detail_tax",
        on_delete=models.CASCADE,
        null=True,
    )
    net = models.ForeignKey(
        Money,
        related_name="claim_item_detail_sub_detail_net",
        on_delete=models.CASCADE,
        null=True,
    )
    udi = models.ManyToManyField(
        "devices.DeviceReference",
        related_name="claim_item_detail_sub_detail_udi",
        blank=True,
    )


class ClaimItemDetail(TimeStampedModel):
    """Claim item detail."""

    sequence = models.IntegerField(null=True)
    trace_number = models.ManyToManyField(
        Identifier,
        related_name="claim_item_detail_trace_number",
        blank=True,
    )
    revenue = models.ForeignKey(
        CodeableConcept,
        related_name="claim_item_detail_revenue",
        on_delete=models.CASCADE,
        null=True,
    )
    category = models.ForeignKey(
        CodeableConcept,
        related_name="claim_item_detail_category",
        on_delete=models.CASCADE,
        null=True,
    )
    product_or_service = models.ForeignKey(
        CodeableConcept,
        related_name="claim_item_detail_product_or_service",
        on_delete=models.CASCADE,
        null=True,
    )
    modifier = models.ManyToManyField(
        CodeableConcept, related_name="claim_item_detail_modifier", blank=True
    )
    program_code = models.ManyToManyField(
        CodeableConcept, related_name="claim_item_detail_program_code", blank=True
    )
    patient_paid = models.ForeignKey(
        Money,
        related_name="claim_item_detail_patient_paid",
        on_delete=models.CASCADE,
        null=True,
    )
    quantity = models.ForeignKey(
        SimpleQuantity,
        related_name="claim_item_detail_quantity",
        on_delete=models.CASCADE,
        null=True,
    )
    unit_price = models.ForeignKey(
        Money,
        related_name="claim_item_detail_unit_price",
        on_delete=models.CASCADE,
        null=True,
    )
    factor = models.FloatField(null=True)
    tax = models.ForeignKey(
        Money, related_name="claim_item_detail_tax", on_delete=models.CASCADE, null=True
    )
    net = models.ForeignKey(
        Money, related_name="claim_item_detail_net", on_delete=models.CASCADE, null=True
    )
    udi = models.ManyToManyField(
        "devices.DeviceReference", related_name="claim_item_detail_udi", blank=True
    )
    sub_detail = models.ManyToManyField(
        ClaimItemDetailSubDetail,
        related_name="claim_item_detail_sub_detail",
        blank=True,
    )


class ClaimItem(TimeStampedModel):
    """Claim item model."""

    sequence = models.IntegerField(null=True)
    trace_number = models.ManyToManyField(
        Identifier,
        related_name="claim_item_trace_number",
        blank=True,
    )
    care_team_sequence = ArrayField(
        models.IntegerField(),
        null=True,
    )
    diagnosis_sequence = ArrayField(
        models.IntegerField(),
        null=True,
    )
    procedure_sequence = ArrayField(
        models.IntegerField(),
        null=True,
    )
    information_sequence = ArrayField(
        models.IntegerField(),
        null=True,
    )
    revenue = models.ForeignKey(
        CodeableConcept,
        related_name="claim_item_revenue",
        on_delete=models.CASCADE,
        null=True,
    )
    category = models.ForeignKey(
        CodeableConcept,
        related_name="claim_item_category",
        on_delete=models.CASCADE,
        null=True,
    )
    product_or_service = models.ForeignKey(
        CodeableConcept,
        related_name="claim_item_product_or_service",
        on_delete=models.CASCADE,
        null=True,
    )
    product_or_service_end = models.ForeignKey(
        CodeableConcept,
        related_name="claim_item_product_or_service_end",
        on_delete=models.CASCADE,
        null=True,
    )
    request = models.ManyToManyField(
        ClaimItemRequestReference, related_name="claim_item_request", blank=True
    )
    modifier = models.ManyToManyField(
        CodeableConcept, related_name="claim_item_modifier", blank=True
    )
    program_code = models.ManyToManyField(
        CodeableConcept, related_name="claim_item_program_code", blank=True
    )
    serviced_date = models.DateField(null=True)
    serviced_period = models.ForeignKey(
        Period,
        related_name="claim_item_serviced_period",
        on_delete=models.CASCADE,
        null=True,
    )
    location_codeable_concept = models.ForeignKey(
        CodeableConcept,
        related_name="claim_item_location_codeable_concept",
        on_delete=models.CASCADE,
        null=True,
    )
    location_address = models.ForeignKey(
        Address,
        related_name="claim_item_location_address",
        on_delete=models.CASCADE,
        null=True,
    )
    location_reference = models.ForeignKey(
        "locations.LocationReference",
        related_name="claim_item_location_reference",
        on_delete=models.CASCADE,
        null=True,
    )
    patient_paid = models.ForeignKey(
        Money,
        related_name="claim_item_patient_paid",
        on_delete=models.CASCADE,
        null=True,
    )
    quantity = models.ForeignKey(
        SimpleQuantity,
        related_name="claim_item_quantity",
        on_delete=models.CASCADE,
        null=True,
    )
    unit_price = models.ForeignKey(
        Money, related_name="claim_item_unit_price", on_delete=models.CASCADE, null=True
    )
    factor = models.FloatField(null=True)
    tax = models.ForeignKey(
        Money, related_name="claim_item_tax", on_delete=models.CASCADE, null=True
    )
    net = models.ForeignKey(
        Money, related_name="claim_item_net", on_delete=models.CASCADE, null=True
    )
    udi = models.ManyToManyField(
        "devices.DeviceReference", related_name="claim_item_udi", blank=True
    )
    body_site = models.ManyToManyField(
        ClaimItemBodySIte, related_name="claim_item_body_site", blank=True
    )
    encounter = models.ManyToManyField(
        "encounters.EncounterReference", related_name="claim_item_encounter", blank=True
    )
    detail = models.ManyToManyField(
        ClaimItemDetail, related_name="claim_item_detail", blank=True
    )


class ClaimEvent(TimeStampedModel):
    """Claim event model."""

    type = models.ForeignKey(
        CodeableConcept,
        related_name="claim_event_type",
        on_delete=models.CASCADE,
        null=True,
    )
    when_date_time = models.DateTimeField(null=True)
    when_period = models.ForeignKey(
        Period,
        related_name="claim_event_when_period",
        on_delete=models.CASCADE,
        null=True,
    )


class Claim(TimeStampedModel):
    """Claim model."""

    identifier = models.ManyToManyField(
        Identifier,
        related_name="claim_identifier",
        blank=True,
    )
    trace_number = models.ManyToManyField(
        Identifier,
        related_name="claim_trace_number",
        blank=True,
    )
    status = models.CharField(
        max_length=255,
        choices=choices.ClaimStatus.choices,
        default=choices.ClaimStatus.DRAFT,
    )
    type = models.ForeignKey(
        CodeableConcept, related_name="claim_type", on_delete=models.CASCADE, null=True
    )
    sub_type = models.ForeignKey(
        CodeableConcept,
        related_name="claim_sub_type",
        null=True,
        on_delete=models.CASCADE,
    )
    use = models.CharField(
        max_length=255,
        choices=choices.ClaimUseChoices.choices,
        default=choices.ClaimUseChoices.CLAIM,
    )
    patient = models.ForeignKey(
        "patients.PatientReference",
        related_name="claim_patient",
        on_delete=models.CASCADE,
        null=True,
    )
    billable_period = models.ForeignKey(
        Period,
        related_name="claim_billable_period",
        on_delete=models.CASCADE,
        null=True,
    )
    created = models.DateTimeField(auto_created=True, null=True)
    enterer = models.ForeignKey(
        ClaimEntererReference,
        related_name="claim_enterer",
        on_delete=models.CASCADE,
        null=True,
    )
    insurer = models.ForeignKey(
        OrganizationReference,
        related_name="claim_insurer",
        on_delete=models.CASCADE,
        null=True,
    )
    provider = models.ForeignKey(
        ClaimProviderReference,
        related_name="claim_provider",
        on_delete=models.CASCADE,
        null=True,
    )
    priority = models.ForeignKey(
        CodeableConcept,
        related_name="claim_priority",
        on_delete=models.CASCADE,
        null=True,
    )
    funds_reserve = models.ForeignKey(
        CodeableConcept,
        related_name="claim_funds_reserve",
        on_delete=models.CASCADE,
        null=True,
    )
    related = models.ManyToManyField(
        ClaimRelated, related_name="claim_related", blank=True
    )
    prescription = models.ForeignKey(
        ClaimPrescriptionReference,
        related_name="claim_prescription",
        on_delete=models.CASCADE,
        null=True,
    )
    original_prescription = models.ForeignKey(
        ClaimOriginalPrescriptionReference,
        related_name="claim_original_prescription",
        on_delete=models.CASCADE,
        null=True,
    )
    payee = models.ForeignKey(
        ClaimPayee, related_name="claim_payee", on_delete=models.CASCADE, null=True
    )
    referral = models.ForeignKey(
        "servicerequests.ServiceRequestReference",
        related_name="claim_referral",
        on_delete=models.CASCADE,
        null=True,
    )
    encounter = models.ManyToManyField(
        "encounters.EncounterReference", related_name="claim_encounter", blank=True
    )
    facility = models.ForeignKey(
        "locations.LocationOrganizationReference",
        related_name="claim_facility",
        on_delete=models.CASCADE,
        null=True,
    )
    diagnosis_related_group = models.ForeignKey(
        CodeableConcept,
        related_name="claim_diagnosis_related_group",
        on_delete=models.CASCADE,
        null=True,
    )
    event = models.ManyToManyField(ClaimEvent, related_name="claim_event", blank=True)
    care_team = models.ManyToManyField(
        ClaimCareTeam, related_name="claim_care_team", blank=True
    )
    supporting_info = models.ManyToManyField(
        ClaimSupportingInfo, related_name="claim_supporting_info", blank=True
    )
    diagnosis = models.ManyToManyField(
        ClaimDiagnosis, related_name="claim_diagnosis", blank=True
    )
    procedure = models.ManyToManyField(
        ClaimProcedure, related_name="claim_procedure", blank=True
    )
    insurance = models.ManyToManyField(
        ClaimInsurance, related_name="claim_insurance", blank=True
    )
    accident = models.ForeignKey(
        ClaimAccident,
        related_name="claim_accident",
        on_delete=models.CASCADE,
        null=True,
    )
    patient_paid = models.ForeignKey(
        Money, related_name="claim_patient_paid", on_delete=models.CASCADE, null=True
    )
    item = models.ManyToManyField(ClaimItem, related_name="claim_item", blank=True)
    total = models.ForeignKey(
        Money, related_name="claim_total", on_delete=models.CASCADE, null=True
    )


class ClaimReference(BaseReference):
    """Claim Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        related_name="claim_reference_identifier",
        on_delete=models.CASCADE,
        null=True,
    )
    claim = models.ForeignKey(
        Claim, related_name="claim_reference_claim", on_delete=models.CASCADE, null=True
    )



# Generated by Django 5.2 on 2025-05-05 14:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('claimresponses', '0005_initial'),
        ('claims', '0004_initial'),
        ('paymentnotices', '0002_initial'),
        ('paymentreconciliations', '0002_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='paymentnotice',
            name='payment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice', to='paymentreconciliations.paymentreconciliation'),
        ),
        migrations.AddField(
            model_name='paymentnoticerequestreference',
            name='claim',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_request_reference', to='claims.claim'),
        ),
        migrations.AddField(
            model_name='paymentnoticeresponsereference',
            name='claim_response',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_response_reference', to='claimresponses.claimresponse'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('medicationadministrations', '0001_initial'),
        ('medicationrequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='medicationadministration',
            name='request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_administration_request', to='medicationrequests.medicationrequestreference'),
        ),
        migrations.AddField(
            model_name='medicationadministration',
            name='status_reason',
            field=models.ManyToManyField(blank=True, related_name='medication_administration_status_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationadministration',
            name='sub_potent_reason',
            field=models.ManyToManyField(blank=True, related_name='medication_administration_sub_potent_reason', to='base.codeableconcept'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.contrib.postgres.fields
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Address',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('use', models.CharField(choices=[('home', 'home'), ('work', 'work'), ('temp', 'temp'), ('old', 'old'), ('billing', 'billing')], max_length=10, null=True)),
                ('type', models.CharField(choices=[('postal', 'postal'), ('physical', 'physical'), ('both', 'both')], max_length=10, null=True)),
                ('text', models.CharField(blank=True, max_length=255, null=True)),
                ('line', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(blank=True, max_length=255, null=True), null=True, size=None)),
                ('city', models.CharField(blank=True, max_length=255, null=True)),
                ('district', models.CharField(blank=True, max_length=255, null=True)),
                ('state', models.CharField(blank=True, max_length=255, null=True)),
                ('postal_code', models.CharField(blank=True, max_length=255, null=True)),
                ('country', models.CharField(blank=True, max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Quantity',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('value', models.DecimalField(decimal_places=2, max_digits=1000, null=True)),
                ('comparator', models.CharField(choices=[('eq', 'Equal'), ('ne', 'Not Equal'), ('gt', 'Greater Than'), ('lt', 'Less Than'), ('ge', 'Greater or Equal'), ('le', 'Less or Equal')], max_length=255, null=True)),
                ('unit', models.CharField(max_length=255, null=True)),
                ('system', models.CharField(max_length=255, null=True)),
                ('code', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Annotation',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('author_string', models.CharField(max_length=255, null=True)),
                ('time', models.DateTimeField(null=True)),
                ('text', models.TextField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Attachment',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('title', models.CharField(blank=True, max_length=255, null=True)),
                ('content_type', models.CharField(blank=True, max_length=255, null=True)),
                ('language', models.CharField(blank=True, max_length=255, null=True)),
                ('data', models.TextField(blank=True, null=True)),
                ('url', models.URLField(blank=True, null=True)),
                ('size', models.BigIntegerField(blank=True, null=True)),
                ('hash', models.BinaryField(blank=True, null=True)),
                ('creation', models.DateTimeField(blank=True, null=True)),
                ('height', models.PositiveIntegerField(blank=True, null=True)),
                ('width', models.PositiveIntegerField(blank=True, null=True)),
                ('frames', models.PositiveIntegerField(blank=True, null=True)),
                ('duration', models.DecimalField(blank=True, decimal_places=2, max_digits=1000, null=True)),
                ('pages', models.PositiveIntegerField(blank=True, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='AvailableTime',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('days_of_week', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(choices=[('mon', 'Monday'), ('tue', 'Tuesday'), ('wed', 'Wednesday'), ('thu', 'Thursday'), ('fri', 'Friday'), ('sat', 'Saturday'), ('sun', 'Sunday')], max_length=255), null=True, size=None)),
                ('all_day', models.BooleanField(default=False)),
                ('available_start_time', models.TimeField(null=True)),
                ('available_end_time', models.TimeField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CodeableConcept',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('text', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Coding',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('system', models.CharField(max_length=255, null=True)),
                ('version', models.CharField(max_length=255, null=True)),
                ('code', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('user_selected', models.BooleanField(default=False)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ConnectionType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('code', models.CharField(max_length=255, null=True)),
                ('system', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('definition', models.TextField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ContactPoint',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('system', models.CharField(blank=True, choices=[('phone', 'phone'), ('fax', 'fax'), ('email', 'email'), ('sms', 'sms'), ('url', 'url'), ('other', 'other')], help_text='Telecommunications form for contact point.', max_length=10, null=True)),
                ('value', models.CharField(blank=True, max_length=255, null=True)),
                ('use', models.CharField(blank=True, choices=[('home', 'home'), ('work', 'work'), ('temp', 'temp'), ('old', 'old'), ('mobile', 'mobile')], max_length=10, null=True)),
                ('rank', models.PositiveIntegerField(blank=True, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Expression',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('description', models.TextField(null=True)),
                ('name', models.CharField(max_length=255, null=True)),
                ('language', models.CharField(max_length=255, null=True)),
                ('expression', models.TextField(null=True)),
                ('reference', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='HumanName',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('use', models.CharField(choices=[('usual', 'usual'), ('official', 'official'), ('temp', 'temp'), ('nickname', 'nickname'), ('anonymous', 'anonymous'), ('old', 'old'), ('maiden', 'maiden')], max_length=255, null=True)),
                ('text', models.TextField(null=True)),
                ('family', models.CharField(max_length=255, null=True)),
                ('given', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=255), null=True, size=None)),
                ('prefix', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=255), null=True, size=None)),
                ('suffix', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=255), null=True, size=None)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Identifier',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('use', models.CharField(max_length=255, null=True)),
                ('system', models.CharField(max_length=255, null=True)),
                ('value', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MonetaryComponent',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('type', models.CharField(choices=[('base', 'base'), ('surcharge', 'surcharge'), ('discount', 'discount'), ('tax', 'tax'), ('informational', 'informational')], max_length=255, null=True)),
                ('factor', models.DecimalField(decimal_places=2, max_digits=1000, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Money',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('value', models.DecimalField(decimal_places=2, max_digits=1000, null=True)),
                ('currency', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='NotAvailableTime',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('description', models.CharField(blank=True, max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OrganizationReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Payload',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('profile_uri', django.contrib.postgres.fields.ArrayField(base_field=models.URLField(max_length=255), null=True, size=None)),
                ('profile_canonical', django.contrib.postgres.fields.ArrayField(base_field=models.URLField(max_length=255), null=True, size=None)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Period',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('start', models.DateTimeField(null=True)),
                ('end', models.DateTimeField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ProductShelfLife',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('period_string', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Qualification',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Range',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Ratio',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Reference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='RelatedArtifact',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('type', models.CharField(choices=[('documentation', 'documentation'), ('justification', 'justification'), ('citation', 'citation'), ('predecessor', 'predecessor'), ('successor', 'successor'), ('derived-from', 'derived-from'), ('depends-on', 'depends-on'), ('composed-of', 'composed-of'), ('part-of', 'part-of'), ('replaces', 'replaces'), ('amends', 'amends'), ('appends', 'appends'), ('transforms', 'transforms'), ('amended-with', 'amended-with'), ('appended-with', 'appended-with'), ('cites', 'cites'), ('cited-by', 'cited-by'), ('comments-on', 'comments-on'), ('comments-in', 'comments-in'), ('contains', 'contains'), ('contained-in', 'contained-in'), ('corrects', 'corrects'), ('correction-in', 'correction-in'), ('replaced-with', 'replaced-with'), ('retracts', 'retracts'), ('retracted-by', 'retracted-by'), ('signs', 'signs'), ('similar-to', 'similar-to'), ('supports', 'supports'), ('supported-with', 'supported-with'), ('transformed-into', 'transformed-into'), ('transformed-with', 'transformed-with'), ('documents', 'documents'), ('specification-of', 'specification-of'), ('created-with', 'created-with'), ('cite-as', 'cite-as')], max_length=255, null=True)),
                ('label', models.CharField(max_length=255, null=True)),
                ('display', models.TextField(null=True)),
                ('citation', models.TextField(null=True)),
                ('publication_status', models.CharField(choices=[('draft', 'draft'), ('active', 'active'), ('retired', 'retired'), ('unknown', 'unknown')], max_length=255, null=True)),
                ('publication_date', models.DateTimeField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='RelativeTime',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('context_path', models.CharField(max_length=255, null=True)),
                ('text', models.TextField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Repeat',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('count', models.PositiveIntegerField(null=True)),
                ('count_max', models.PositiveIntegerField(null=True)),
                ('duration', models.DecimalField(decimal_places=2, max_digits=1000, null=True)),
                ('duration_max', models.DecimalField(decimal_places=2, max_digits=1000, null=True)),
                ('duration_unit', models.CharField(choices=[('s', 'second'), ('min', 'minute'), ('h', 'hour'), ('d', 'day'), ('wk', 'week'), ('mo', 'month'), ('yr', 'year')], max_length=255, null=True)),
                ('frequency', models.PositiveIntegerField(null=True)),
                ('frequency_max', models.PositiveIntegerField(null=True)),
                ('period', models.DecimalField(decimal_places=2, max_digits=1000, null=True)),
                ('period_max', models.DecimalField(decimal_places=2, max_digits=1000, null=True)),
                ('period_unit', models.CharField(choices=[('s', 'second'), ('min', 'minute'), ('h', 'hour'), ('d', 'day'), ('wk', 'week'), ('mo', 'month'), ('yr', 'year')], max_length=255, null=True)),
                ('time_of_day', models.TimeField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Signature',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('when', models.DateTimeField(null=True)),
                ('target_format', models.CharField(max_length=255, null=True)),
                ('sig_format', models.CharField(max_length=255, null=True)),
                ('data', models.TextField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SignatureOnBehalfOfReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SignatureWhoReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Timing',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('event', models.DateTimeField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TriggerDefinition',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('type', models.CharField(choices=[('named-event', 'Named Event'), ('periodic', 'Periodic'), ('data-changed', 'Data Changed'), ('data-added', 'Data Added'), ('data-modified', 'Data Modified'), ('data-removed', 'Data Removed'), ('data-accessed', 'Data Accessed'), ('data-accessed-ended', 'Data Accessed Ended')], max_length=255, null=True)),
                ('name', models.CharField(max_length=255, null=True)),
                ('timing_date', models.DateField(null=True)),
                ('timing_date_time', models.DateTimeField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='UsageContext',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='VirtualServiceDetailAddress',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('address_url', models.URLField(max_length=255, null=True)),
                ('address_string', models.TextField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='VirtualServiceDetails',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('additional_info', django.contrib.postgres.fields.ArrayField(base_field=models.URLField(max_length=255), null=True, size=None)),
                ('max_participants', models.PositiveIntegerField(null=True)),
                ('session_key', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Age',
            fields=[
                ('quantity_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='base.quantity')),
            ],
            options={
                'abstract': False,
            },
            bases=('base.quantity',),
        ),
        migrations.CreateModel(
            name='Duration',
            fields=[
                ('quantity_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='base.quantity')),
            ],
            options={
                'abstract': False,
            },
            bases=('base.quantity',),
        ),
        migrations.CreateModel(
            name='SimpleQuantity',
            fields=[
                ('quantity_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='base.quantity')),
            ],
            options={
                'abstract': False,
            },
            bases=('base.quantity',),
        ),
        migrations.CreateModel(
            name='Availability',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('available_time', models.ManyToManyField(blank=True, related_name='availability_available_time', to='base.availabletime')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CodeableReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('concept', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='codeable_reference_concept', to='base.codeableconcept')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='codeableconcept',
            name='coding',
            field=models.ManyToManyField(related_name='codeable_concept', to='base.coding'),
        ),
        migrations.CreateModel(
            name='Communication',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('preferred', models.BooleanField(default=False)),
                ('language', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='communication_language', to='base.codeableconcept')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ContactDetail',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('name', models.CharField(blank=True, max_length=255, null=True)),
                ('telecom', models.ManyToManyField(blank=True, related_name='contact_detail_telecom', to='base.contactpoint')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ExtendedContactDetail',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('system', models.CharField(blank=True, choices=[('phone', 'phone'), ('fax', 'fax'), ('email', 'email'), ('sms', 'sms'), ('url', 'url'), ('other', 'other')], help_text='Telecommunications form for contact point.', max_length=10, null=True)),
                ('address', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='extended_contact_detail_address', to='base.address')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



"""supply requests views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from dfhir.supplyrequests.models import SupplyRequest
from dfhir.supplyrequests.serializers import SupplyRequestSerializer


class SupplyRequestListView(APIView):
    """supply request list view."""

    permission_classes = (AllowAny,)

    @extend_schema(responses={200: SupplyRequestSerializer(many=True)})
    def get(self, request):
        """Get supply request objects."""
        supply_requests = SupplyRequest.objects.all()
        serializer = SupplyRequestSerializer(supply_requests, many=True)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(
        request=SupplyRequestSerializer, responses={201: SupplyRequestSerializer}
    )
    def post(self, request):
        """Create supply request object."""
        serializer = SupplyRequestSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_201_CREATED)


class SupplyRequestDetailView(APIView):
    """supply request detailed view."""

    def get_object(self, pk):
        """Get supply request object by pk."""
        try:
            return SupplyRequest.objects.get(pk=pk)
        except SupplyRequest.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses={200: SupplyRequestSerializer})
    def get(self, request, pk):
        """Get supply request object by pk."""
        supply_request = self.get_object(pk)
        serializer = SupplyRequestSerializer(supply_request)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={200: SupplyRequestSerializer})
    def patch(self, request, pk):
        """Updated a supply request object."""
        supply_request = self.get_object(pk)
        serializer = SupplyRequestSerializer(
            supply_request, data=request.data, partial=True
        )
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={204: None})
    def delete(self, request, pk):
        """Delete a supply request object."""
        supply_request = self.get_object(pk)
        supply_request.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



"""Clinical impression views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from .models import ClinicalImpression
from .serializers import ClinicalImpressionSerializer


class ClinicalImpressionListView(APIView):
    """Clinical impression create view."""

    permission_classes = [AllowAny]

    @extend_schema(
        request=ClinicalImpressionSerializer,
        responses={201: ClinicalImpressionSerializer},
    )
    def post(self, request):
        """Create a clinical impression."""
        serializer = ClinicalImpressionSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()

        return Response(serializer.data, status=status.HTTP_201_CREATED)

    @extend_schema(responses={200: ClinicalImpressionSerializer})
    def get(self, request):
        """Get all clinical impressions."""
        clinical_impressions = ClinicalImpression.objects.all()
        serializer = ClinicalImpressionSerializer(clinical_impressions, many=True)

        return Response(serializer.data, status=status.HTTP_200_OK)


class ClinicalImpressionsDetailView(APIView):
    """Clinical impression detail view."""

    permission_classes = [AllowAny]

    def get_object(self, pk):
        """Get clinical impression object."""
        try:
            return ClinicalImpression.objects.get(pk=pk)
        except ClinicalImpression.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses={200: ClinicalImpressionSerializer})
    def get(self, request, pk=None):
        """Get a clinical impression."""
        queryset = self.get_object(pk)
        serializer = ClinicalImpressionSerializer(queryset)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={200: ClinicalImpressionSerializer})
    def patch(self, request, pk=None):
        """Update a clinical impression."""
        queryset = self.get_object(pk)
        serializer = ClinicalImpressionSerializer(
            queryset, data=request.data, partial=True
        )
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    def delete(self, request, pk=None):
        """Delete a clinical impression."""
        clinical_impression = self.get_object(pk)
        clinical_impression.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('deviceassociations', '0001_initial'),
        ('devices', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='deviceassociation',
            name='device',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='device_association_device', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='deviceassociation',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='device_association_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='deviceassociation',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='device_association_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='deviceassociation',
            name='relationship',
            field=models.ManyToManyField(blank=True, related_name='device_association_relationship', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='deviceassociation',
            name='status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='device_association_status', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='deviceassociation',
            name='status_reason',
            field=models.ManyToManyField(blank=True, related_name='device_association_status_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='deviceassociationoperation',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='device_association_operation_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='deviceassociationoperation',
            name='status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='device_association_operation_status', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='deviceassociation',
            name='operation',
            field=models.ManyToManyField(blank=True, related_name='device_association_operation', to='deviceassociations.deviceassociationoperation'),
        ),
        migrations.AddField(
            model_name='deviceassociationoperationoperatorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='device_association_operation_operator_reference_identifier', to='base.identifier'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('careteams', '0002_initial'),
        ('devicerequests', '0001_initial'),
        ('devices', '0001_initial'),
        ('encounters', '0001_initial'),
        ('healthcareservices', '0001_initial'),
        ('organizations', '0001_initial'),
        ('provenances', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='devicerequest',
            name='encounter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='devicerequest',
            name='group_identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_group_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='devicerequest',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='device_request_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='devicerequest',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='device_request_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='devicerequest',
            name='occurrence_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_occurrence_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='devicerequest',
            name='occurrence_timing',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='device_request_occurrence_timing', to='base.timing'),
        ),
        migrations.AddField(
            model_name='devicerequest',
            name='relevant_history',
            field=models.ManyToManyField(blank=True, related_name='device_request_relevant_history', to='provenances.provenancereference'),
        ),
        migrations.AddField(
            model_name='devicerequest',
            name='supporting_info',
            field=models.ManyToManyField(blank=True, related_name='device_request_supporting_info', to='base.reference'),
        ),
        migrations.AddField(
            model_name='devicerequestparameter',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_parameter_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='devicerequestparameter',
            name='value_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_parameter_value_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='devicerequestparameter',
            name='value_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_parameter_value_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='devicerequestparameter',
            name='value_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_parameter_value_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='devicerequest',
            name='parameter',
            field=models.ManyToManyField(blank=True, related_name='device_request_parameter', to='devicerequests.devicerequestparameter'),
        ),
        migrations.AddField(
            model_name='devicerequestperformercodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_performer_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='devicerequest',
            name='performer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_performer', to='devicerequests.devicerequestperformercodeablereference'),
        ),
        migrations.AddField(
            model_name='devicerequestperformerreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_performer_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='devicerequestperformerreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_performer_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='devicerequestperformerreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_performer_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='devicerequestperformerreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_performer_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='devicerequestperformerreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_performer_reference_organization', to='organizations.organization'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('groups', '0002_initial'),
        ('specimens', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='specimen',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_specimen', to='specimens.specimen'),
        ),
        migrations.AddField(
            model_name='groupmember',
            name='entity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity', to='groups.groupmemberentityreference'),
        ),
        migrations.AddField(
            model_name='groupreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='groupreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_reference_identifier', to='base.identifier'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('allergyintolerances', '0005_initial'),
        ('base', '0005_initial'),
        ('biologicallyderivedproducts', '0002_initial'),
        ('careplans', '0005_initial'),
        ('devices', '0001_initial'),
        ('deviceusages', '0002_initial'),
        ('diagnosticreports', '0002_initial'),
        ('documentreferences', '0004_initial'),
        ('familymemberhistories', '0003_initial'),
        ('groups', '0002_initial'),
        ('healthcareservices', '0001_initial'),
        ('imagingstudies', '0001_initial'),
        ('immunizationrecommendations', '0002_initial'),
        ('locations', '0001_initial'),
        ('medicationrequests', '0002_initial'),
        ('medications', '0001_initial'),
        ('nutritionorders', '0002_initial'),
        ('observations', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('specimens', '0001_initial'),
        ('substances', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='diagnosticreport',
            name='specimen',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_report_specimen', to='specimens.specimenreference'),
        ),
        migrations.AddField(
            model_name='diagnosticreportbasedonreference',
            name='Immunization_recommendation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_based_on_immunization_recommendation', to='immunizationrecommendations.immunizationrecommendation'),
        ),
        migrations.AddField(
            model_name='diagnosticreportbasedonreference',
            name='careplan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_based_on_careplan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='diagnosticreportbasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_based_on_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='diagnosticreportbasedonreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_based_on_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='diagnosticreportbasedonreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_based_on_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
        migrations.AddField(
            model_name='diagnosticreportbasedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_based_on_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_report_based_on', to='diagnosticreports.diagnosticreportbasedonreference'),
        ),
        migrations.AddField(
            model_name='diagnosticreportdocumentreferencereference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='diagnosticreportdocumentreferencereference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_reference_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='diagnosticreportdocumentreferencereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='diagnosticreporteffective',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='base.period'),
        ),
        migrations.AddField(
            model_name='diagnosticreportmedia',
            name='link',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_media_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='media',
            field=models.ManyToManyField(blank=True, to='diagnosticreports.diagnosticreportmedia'),
        ),
        migrations.AddField(
            model_name='diagnosticreportperformerreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='performer_care_plan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='diagnosticreportperformerreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='performer_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='diagnosticreportperformerreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='performer_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='diagnosticreportperformerreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='performer_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='diagnosticreportperformerreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='performer_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_report_performer', to='diagnosticreports.diagnosticreportperformerreference'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='results_interpretation',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_results_interpretation', to='diagnosticreports.diagnosticreportperformerreference'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='biologically_derived_product',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_reference_biologically_derived_product', to='biologicallyderivedproducts.biologicallyderivedproduct'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='locations.location'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_reference_medication', to='medications.medication'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='diagnosticreports.diagnosticreportsubjectreference'),
        ),
        migrations.AddField(
            model_name='supportinginfo',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='supporting_info',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_report_supporting_info', to='diagnosticreports.supportinginfo'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='allergy_intolerance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_allergy_intolerance', to='allergyintolerances.allergyintolerance'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='device_usage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_device_usage', to='deviceusages.deviceusage'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='family_member_history',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_family_member_history', to='familymemberhistories.familymemberhistory'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='imaging_study',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_imaging_study', to='imagingstudies.imagingstudy'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='supportinginfo',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='supporting_info_reference', to='diagnosticreports.supportinginforeference'),
        ),
    ]



"""observations urls."""

from django.urls import path

from . import views

app_name = "observations"

urlpatterns = [
    path("observations/", views.ObservationListView.as_view(), name="list_view"),
    path(
        "observations/<int:pk>/",
        views.ObservationDetailView.as_view(),
        name="detail_view",
    ),
]



"""Contrib sites."""

# """To understand why this file is here, please read:
#
# http://cookiecutter-django.readthedocs.io/en/latest/faq.html#why-is-there-a-django-contrib-sites-directory-in-cookiecutter-django.
# """



"""Detected issues models."""

from django.db import models

from dfhir.base.models import (
    Annotation,
    BaseReference,
    CodeableConcept,
    Identifier,
    Period,
    Reference,
    TimeStampedModel,
)
from dfhir.practitioners.models import PractitionerPractitionerRoleReference

from . import choices


class DetectedIssueSubjectReference(BaseReference):
    """Detected issue subject reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_subject_reference_identifier",
    )
    patient = models.ForeignKey(
        "patients.Patient",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_subject_reference_patient",
    )
    group = models.ForeignKey(
        "groups.Group",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_subject_reference_group",
    )
    device = models.ForeignKey(
        "devices.Device",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_subject_reference_device",
    )
    location = models.ForeignKey(
        "locations.Location",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_subject_reference_location",
    )
    organization = models.ForeignKey(
        "organizations.Organization",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_subject_reference_organization",
    )
    procedure = models.ForeignKey(
        "procedures.Procedure",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_subject_reference_procedure",
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_subject_reference_practitioner",
    )
    medication = models.ForeignKey(
        "medications.Medication",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_subject_reference_medication",
    )
    biologically_derived_product = models.ForeignKey(
        "biologicallyderivedproducts.BiologicallyDerivedProduct",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_subject_reference_biologically_derived_product",
    )
    nutrition_product = models.ForeignKey(
        "nutritionproducts.NutritionProduct",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_subject_reference_nutrition_product",
    )
    substance = models.ForeignKey(
        "substances.Substance",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_subject_reference_substance",
    )


class DetectedIssueAuthorReference(BaseReference):
    """Detected issue author reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_author_reference_identifier",
    )
    patient = models.ForeignKey(
        "patients.Patient",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_author_reference_patient",
    )
    related_person = models.ForeignKey(
        "relatedpersons.RelatedPerson",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_author_reference_related_person",
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_author_reference_practitioner",
    )
    practitioner_role = models.ForeignKey(
        "practitionerroles.PractitionerRole",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_author_reference_practitioner_role",
    )

    device = models.ForeignKey(
        "devices.Device",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_author_reference_device",
    )


class DetectedIssueEvidence(TimeStampedModel):
    """Detected issue evidence model."""

    code = models.ManyToManyField(
        CodeableConcept,
        blank=True,
        related_name="detected_issue_evidence_code",
    )
    detail = models.ManyToManyField(
        Reference, blank=True, related_name="detected_issue_evidence_detail"
    )


class DetectedIssueMitigation(TimeStampedModel):
    """Detected issue mitigation model."""

    action = models.ForeignKey(
        CodeableConcept,
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_mitigation_action",
    )
    date = models.DateTimeField(null=True)
    author = models.ForeignKey(
        PractitionerPractitionerRoleReference,
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_mitigation_author",
    )
    note = models.ManyToManyField(
        Annotation, blank=True, related_name="detected_issue_mitigation_note"
    )


class DetectedIssue(TimeStampedModel):
    """Detected issue model."""

    identifier = models.ManyToManyField(
        Identifier, blank=True, related_name="detected_issue_identifier"
    )
    status = models.CharField(
        max_length=255, null=True, choices=choices.DetectedIssueStatusChoices.choices
    )
    category = models.ManyToManyField(
        CodeableConcept,
        blank=True,
        related_name="detected_issue_category",
    )
    code = models.ForeignKey(
        CodeableConcept,
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_code",
    )
    severity = models.CharField(
        max_length=255, null=True, choices=choices.DetectedIssueSeverityChoices.choices
    )
    subject = models.ForeignKey(
        DetectedIssueSubjectReference,
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_patient",
    )
    encounter = models.ForeignKey(
        "encounters.EncounterReference",
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_encounter",
    )
    identified_date_time = models.DateTimeField(null=True)
    identified_period = models.ForeignKey(Period, on_delete=models.SET_NULL, null=True)
    author = models.ForeignKey(
        DetectedIssueAuthorReference,
        on_delete=models.SET_NULL,
        null=True,
        related_name="detected_issue_author",
    )
    implicated = models.ManyToManyField(
        Reference,
        blank=True,
        related_name="detected_issue_implicated",
    )
    evidence = models.ManyToManyField(
        DetectedIssueEvidence, blank=True, related_name="detected_issue_evidence"
    )
    detail = models.TextField(null=True)
    reference = models.URLField(null=True)
    mitigation = models.ManyToManyField(
        DetectedIssueMitigation, blank=True, related_name="detected_issue_mitigation"
    )


class DetectedIssueReference(BaseReference):
    """detected issue reference."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="detected_issue_reference_identifier",
    )
    detected_issue = models.ForeignKey(
        DetectedIssue,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="detected_issue_reference_detected_issue",
    )


class DetectedIssueCodeableReference(TimeStampedModel):
    """detected issue codeable reference."""

    concept = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="detected_issue_codeable_reference_concept",
    )
    reference = models.ForeignKey(
        DetectedIssueReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="detected_issue_codeable_reference_reference",
    )



"""CareTeam URL Configuration."""

from django.urls import path

from . import views

app_name = "careteams"

urlpatterns = [
    path("careteams/", views.CareTeamListView.as_view()),
    path("careteams/<int:pk>/", views.CareTeamDetailView.as_view()),
]



"""CoverageEligibilityResponses models."""

from django.contrib.postgres.fields import ArrayField
from django.db import models

from dfhir.base.models import (
    BaseReference,
    CodeableConcept,
    Identifier,
    Money,
    OrganizationReference,
    Period,
    TimeStampedModel,
)

from . import choices


class CoverageEligibilityResponseEvent(TimeStampedModel):
    """Coverage Eligibility Response Event model."""

    type = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_event_type",
    )
    when_date_time = models.DateTimeField(null=True)
    when_period = models.ForeignKey(
        Period,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_event_when_period",
        null=True,
    )


class CoverageEligibilityResponseInsuranceItemBenefit(TimeStampedModel):
    """Coverage Eligibility Response Insurance Item Benefit model."""

    type = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_insurance_item_benefit_type",
    )
    allowed_string = models.CharField(max_length=255, null=True)
    allowed_unsigned_int = models.PositiveIntegerField(null=True)
    allowed_money = models.ForeignKey(
        Money,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_insurance_item_benefit_allowed_money",
        null=True,
    )
    used_string = models.CharField(max_length=255, null=True)
    used_unsigned_int = models.PositiveIntegerField(null=True)
    used_money = models.ForeignKey(
        Money,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_insurance_item_benefit_used_money",
        null=True,
    )


class CoverageEligibilityResponseInsuranceItem(TimeStampedModel):
    """Coverage Eligibility Response Insurance Item model."""

    category = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_insurance_item_category",
        null=True,
    )
    product_or_service = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_insurance_item_product_or_service",
        null=True,
    )
    modifier = models.ManyToManyField(
        CodeableConcept,
        related_name="coverage_eligibility_response_insurance_item_modifier",
    )
    provider = models.ForeignKey(
        "practitioners.PractitionerPractitionerRoleReference",
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_insurance_item_provider",
        null=True,
    )
    excluded = models.BooleanField(default=False)
    name = models.CharField(max_length=255, null=True)
    description = models.TextField(null=True)
    network = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_insurance_item_network",
        null=True,
    )
    unit = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_insurance_item_unit_price",
        null=True,
    )
    term = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_insurance_item_term",
        null=True,
    )
    benefit = models.ManyToManyField(
        CoverageEligibilityResponseInsuranceItemBenefit,
        related_name="coverage_eligibility_response_insurance_item_benefit",
        blank=True,
    )
    authorization_required = models.BooleanField(default=False)
    authorization_supporting = models.ManyToManyField(
        CodeableConcept,
        related_name="coverage_eligibility_response_insurance_item_authorization_supporting",
        blank=True,
    )
    authorization_url = models.URLField(null=True)


class CoverageEligibilityResponseError(TimeStampedModel):
    """Coverage Eligibility Response Error model."""

    code = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_error_code",
        null=True,
    )
    expression = ArrayField(models.CharField(max_length=255), null=True)


class CoverageEligibilityResponseInsurance(TimeStampedModel):
    """Coverage Eligibility Response Insurance model."""

    coverage = models.ForeignKey(
        "coverages.CoverageReference",
        on_delete=models.CASCADE,
        null=True,
        related_name="coverage_eligibility_response_insurance_coverage",
    )
    inforce = models.BooleanField(default=False)  # codespell:ignore inforce
    benefit_period = models.ForeignKey(
        Period,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_insurance_benefit_period",
        null=True,
    )
    item = models.ManyToManyField(
        CoverageEligibilityResponseInsuranceItem,
        related_name="coverage_eligibility_response_insurance_item",
        blank=True,
    )


class CoverageEligibilityResponseRequesterReference(BaseReference):
    """Coverage Eligibility Response Requester Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_requester_reference_identifier",
        null=True,
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_requester_reference_practitioner",
        null=True,
    )
    practitioner_role = models.ForeignKey(
        "practitionerroles.PractitionerRole",
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_requester_reference_practitioner_role",
        null=True,
    )

    organization = models.ForeignKey(
        OrganizationReference,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_requester_reference_organization",
        null=True,
    )


class CoverageEligibilityResponse(TimeStampedModel):
    """Coverage Eligibility Responses model."""

    identifier = models.ManyToManyField(
        Identifier,
        related_name="coverage_eligibility_response_identifier",
        blank=True,
    )
    status = models.CharField(
        max_length=255,
        choices=choices.CoverageEligibilityResponseStatus.choices,
        default=choices.CoverageEligibilityResponseStatus.ACTIVE,
    )
    purpose = ArrayField(
        models.CharField(
            max_length=255,
            choices=choices.CoverageEligibilityResponsePurpose.choices,
            default=choices.CoverageEligibilityResponsePurpose.AUTH_REQUIREMENTS,
        )
    )
    patient = models.ForeignKey(
        "patients.PatientReference",
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_patient",
    )
    event = models.ManyToManyField(
        CoverageEligibilityResponseEvent,
        related_name="coverage_eligibility_response_event",
        blank=True,
    )
    serviced_date = models.DateField(null=True)
    serviced_period = models.ForeignKey(
        Period,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_serviced_period",
        null=True,
    )
    created = models.DateTimeField(null=True)
    requestor = models.ForeignKey(  # codespell:ignore requestor
        CoverageEligibilityResponseRequesterReference,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_requestor",
        null=True,
    )
    # request = models.ForeignKey(
    #     "coverageeligibilityrequests.CoverageEligibilityRequestReference",
    #     on_delete=models.CASCADE,
    #     related_name="coverage_eligibility_response_request",
    #     null=True,
    # )
    outcome = models.CharField(
        max_length=255,
        choices=choices.CoverageEligibilityResponseOutcome.choices,
        default=choices.CoverageEligibilityResponseOutcome.QUEUED,
    )
    disposition = models.TextField(null=True)
    insurer = models.ForeignKey(
        OrganizationReference,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_insurer",
    )
    insurance = models.ManyToManyField(
        CoverageEligibilityResponseInsurance,
        related_name="coverage_eligibility_response_insurance",
        blank=True,
    )
    pre_auth_ref = models.CharField(max_length=255, null=True)
    form = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="coverage_eligibility_response_form",
        null=True,
    )
    error = models.ManyToManyField(
        CoverageEligibilityResponseError,
        related_name="coverage_eligibility_response_error",
        blank=True,
    )



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('careplans', '0004_initial'),
        ('immunizationrecommendations', '0002_initial'),
        ('immunizations', '0001_initial'),
        ('medicationrequests', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='immunization',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='route',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_route', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='site',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_site', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='status_reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_status_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='subpotent_reason',
            field=models.ManyToManyField(blank=True, related_name='immunization_subpotent_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='supporting_infortmation',
            field=models.ManyToManyField(blank=True, related_name='immunization_supporting_infortmation', to='base.reference'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='vaccine_code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_vaccine_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunizationbasedonreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_based_on_references', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='immunizationbasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_based_on_references', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='immunizationbasedonreference',
            name='immunization_recommendation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_based_on_references', to='immunizationrecommendations.immunizationrecommendation'),
        ),
        migrations.AddField(
            model_name='immunizationbasedonreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_based_on_references', to='medicationrequests.medicationrequest'),
        ),
    ]



"""Personal Relationships models."""

from django.db import models

from dfhir.base.models import (
    BaseReference,
    CodeableConcept,
    Identifier,
    OrganizationReference,
    Period,
    TimeStampedModel,
)


class PersonalRelationshipSourceReference(BaseReference):
    """Personal Relationship Source Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        related_name="personal_relationship_source_reference_identifier",
        on_delete=models.CASCADE,
        null=True,
    )
    patient = models.ForeignKey(
        "patients.Patient",
        related_name="personal_relationship_source_reference_patient",
        on_delete=models.CASCADE,
        null=True,
    )
    related_person = models.ForeignKey(
        "relatedpersons.RelatedPerson",
        related_name="personal_relationship_source_reference_related_person",
        on_delete=models.CASCADE,
        null=True,
    )
    person = models.ForeignKey(
        "persons.Person",
        related_name="personal_relationship_source_reference_person",
        on_delete=models.CASCADE,
        null=True,
    )


class PersonalRelationshipTargetReference(PersonalRelationshipSourceReference):
    """Personal Relationship Target Reference model."""


class PersonalRelationshipAsserterReference(BaseReference):
    """Personal Relationship Asserter Reference model."""

    identifier = models.ForeignKey(
        Identifier,
        related_name="personal_relationship_asserter_reference_identifier",
        on_delete=models.CASCADE,
        null=True,
    )
    patient = models.ForeignKey(
        "patients.Patient",
        related_name="personal_relationship_asserter_reference_patient",
        on_delete=models.CASCADE,
        null=True,
    )
    related_person = models.ForeignKey(
        "relatedpersons.RelatedPerson",
        related_name="personal_relationship_asserter_reference_related_person",
        on_delete=models.CASCADE,
        null=True,
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        related_name="personal_relationship_asserter_reference_practitioner",
        on_delete=models.CASCADE,
        null=True,
    )
    organization = models.ForeignKey(
        "organizations.Organization",
        related_name="personal_relationship_asserter_reference_organization",
        on_delete=models.CASCADE,
        null=True,
    )


class PersonalRelationship(TimeStampedModel):
    """PersonalRelationship model."""

    source = models.ForeignKey(
        PersonalRelationshipSourceReference,
        related_name="personal_relationships_source",
        on_delete=models.CASCADE,
    )
    relationship_type = models.ForeignKey(
        CodeableConcept,
        related_name="personal_relationships_relationship_type",
        on_delete=models.CASCADE,
    )
    target = models.ForeignKey(
        PersonalRelationshipTargetReference,
        related_name="personal_relationships_target",
        on_delete=models.CASCADE,
    )
    period = models.ManyToManyField(
        Period,
        related_name="personal_relationships_period",
        blank=True,
    )
    confidence = models.ForeignKey(
        CodeableConcept,
        related_name="personal_relationships_confidence",
        on_delete=models.CASCADE,
        null=True,
    )
    asserter = models.ForeignKey(
        OrganizationReference,
        related_name="personal_relationships_asserter",
        on_delete=models.CASCADE,
        null=True,
    )
    group = models.ManyToManyField(
        "groups.GroupReference",
        related_name="personal_relationships_group",
        blank=True,
    )
